@@ -1,7 +1,7 @@
 from typing import List
 
-from codemie_tools.base.base_toolkit import BaseToolkit
 from codemie_tools.base.models import ToolKit, ToolSet, Tool
+from ...base.base_toolkit import DiscoverableToolkit
 from .github.tools import GithubTool
 from .github.tools_vars import GITHUB_TOOL
 from .gitlab.tools import GitlabTool
@@ -16,15 +16,8 @@ class VcsToolkitUI(ToolKit):
     ]
 
 
-class VcsToolkit(BaseToolkit):
+class VcsToolkit(DiscoverableToolkit):
 
     @classmethod
     def get_definition(cls):
         return VcsToolkitUI()
-
-    @classmethod
-    def get_tools_ui_info(cls):
-        return cls.get_definition().model_dump()
-
-    def get_tools(self) -> list:
-        return []
